==> aidlab_sdk-0.0.19.tar.gz: lib/src/api/aidlab_delegate.dart <==
import 'package:aidlab_sdk/src/api/disconnect_reason.dart';

import 'body_position.dart';
import 'wear_state.dart';
import 'activity_type.dart';
import 'aidlab.dart';
import 'exercise.dart';

abstract class AidlabDelegate {
  void didConnectAidlab(Aidlab aidlab);

  void didDisconnectAidlab(Aidlab? aidlab, DisconnectReason reason);

  void didReceiveECG(Aidlab aidlab, int timestamp, List<double> values);

  void didReceiveRespiration(Aidlab aidlab, int timestamp, List<double> values);

  void didReceiveRespirationRate(Aidlab aidlab, int timestamp, int value);

  void didReceiveBatteryLevel(Aidlab aidlab, int stateOfCharge);

  void didReceiveSkinTemperature(Aidlab aidlab, int timestamp, double value);

  void didReceiveAccelerometer(
      Aidlab aidlab, int timestamp, double ax, double ay, double az);

  void didReceiveGyroscope(
      Aidlab aidlab, int timestamp, double qx, double qy, double qz);

  void didReceiveMagnetometer(
      Aidlab aidlab, int timestamp, double mx, double my, double mz);

  void didReceiveQuaternion(
      Aidlab aidlab, int timestamp, double qw, double qx, double qy, double qz);

  void didReceiveOrientation(
      Aidlab aidlab, int timestamp, double roll, double pitch, double yaw);

  void didReceiveBodyPosition(
      Aidlab aidlab, int timestamp, BodyPosition bodyPosition);

  void didReceiveActivity(Aidlab aidlab, int timestamp, ActivityType activity);

  void didReceiveSteps(Aidlab aidlab, int timestamp, int steps);

  void didReceiveHeartRate(Aidlab aidlab, int timestamp, int heartRate);

  void didReceiveHrv(Aidlab aidlab, int timestamp, int hrv);

  void wearStateDidChange(Aidlab aidlab, WearState wearState);

  void didDetectExercise(Aidlab aidlab, Exercise exercise);

  void didReceiveSoundVolume(Aidlab aidlab, int timestamp, int value);

  void didReceiveCommand(Aidlab aidlab);

  void didReceiveError(String error);

  void didReceiveMessage(Aidlab aidlab, String process, String message);

  void didDetectUserEvent(Aidlab aidlab, int timestamp);

  void didReceiveSoundFeatures(Aidlab aidlab, List<double> values);

  void didReceiveSignalQuality(Aidlab aidlab, int timestamp, int value);
}

==> aidlab_sdk-0.2.0.tar.gz: lib/src/api/aidlab_delegate.dart <==
import 'package:aidlab_sdk/src/api/disconnect_reason.dart';

import 'body_position.dart';
import 'wear_state.dart';
import 'activity_type.dart';
import 'aidlab.dart';
import 'exercise.dart';

abstract class AidlabDelegate {
  void didConnectAidlab(Aidlab aidlab);

  void didDisconnectAidlab(Aidlab? aidlab, DisconnectReason reason);

  void didReceiveECG(Aidlab aidlab, int timestamp, List<double> values);

  void didReceiveRespiration(Aidlab aidlab, int timestamp, List<double> values);

  void didReceiveRespirationRate(Aidlab aidlab, int timestamp, int value);

  void didReceiveBatteryLevel(Aidlab aidlab, int stateOfCharge);

  void didReceiveSkinTemperature(Aidlab aidlab, int timestamp, double value);

  void didReceiveAccelerometer(
      Aidlab aidlab, int timestamp, double ax, double ay, double az);

  void didReceiveGyroscope(
      Aidlab aidlab, int timestamp, double qx, double qy, double qz);

  void didReceiveMagnetometer(
      Aidlab aidlab, int timestamp, double mx, double my, double mz);

  void didReceiveQuaternion(
      Aidlab aidlab, int timestamp, double qw, double qx, double qy, double qz);

  void didReceiveOrientation(
      Aidlab aidlab, int timestamp, double roll, double pitch, double yaw);

  void didReceiveBodyPosition(
      Aidlab aidlab, int timestamp, BodyPosition bodyPosition);

  void didReceiveActivity(Aidlab aidlab, int timestamp, ActivityType activity);

  void didReceiveSteps(Aidlab aidlab, int timestamp, int steps);

  void didReceiveHeartRate(Aidlab aidlab, int timestamp, int heartRate);

  void didReceiveRr(Aidlab aidlab, int timestamp, int rr);

  void wearStateDidChange(Aidlab aidlab, WearState wearState);

  void didDetectExercise(Aidlab aidlab, Exercise exercise);

  void didReceiveSoundVolume(Aidlab aidlab, int timestamp, int value);

  void didReceiveCommand(Aidlab aidlab);

  void didReceiveError(String error);

  void didReceiveMessage(Aidlab aidlab, String process, String message);

  void didDetectUserEvent(Aidlab aidlab, int timestamp);

  void didReceiveSoundFeatures(Aidlab aidlab, List<double> values);

  void didReceiveSignalQuality(Aidlab aidlab, int timestamp, int value);
}
